#!/bin/bash

#author: pauli8585@hotmail.com
#script name: simple_pip.sh
#script version: 1.4

. /etc/vdr/simple_pip.conf

res_x=0
res_y=0
channel_last=0
pid=0
wid=0
xine_sessions=0
channel=0
size=0
position=0

function get_resolution() {
   res=$(xrandr | grep \* | cut -d " " -f4)
   res_x=$(echo $res | cut -d "x" -f1)
   res_y=$(echo $res | cut -d "x" -f2)
}

function get_last_channel() {
   channel_last=$(svdrpsend -p $svdrp_port LSTC | grep 250 | tail -n1 | cut -d " " -f2)
}

function start() {
   get_resolution
   get_last_channel
   focus_current=$(xdotool getwindowfocus)
   xine_sessions=$(ps uxc | grep xine | wc -l)
   xine $additional_xine_parameters --audio-driver none --no-mouse --no-gui --no-splash --no-logo -B --geometry 1x1+0+0 &
   pid=$!
   for i in `seq 1 10`; do
      info=$(xwininfo -int -root -tree | grep xine | grep 1x1)
      xwin=$(echo $info | cut -d " " -f1)
      if [ ! -z $xwin ]; then
         wid=$xwin
         break
      fi
      sleep 1
   done
   if [ ! -z $focus_current ]; then 
      xdotool windowfocus $focus_current
   fi
}

function set_size_and_position() {
   w=$(($res_x * $size / 100))
   h=$(($res_y * $size / 100))
   if [ $position -eq 0 ]; then
      x=$(($res_x - $w - $video_offset_pixel))
      y=$video_offset_pixel
   elif [ $position -eq 1 ]; then
      x=$(($res_x - $w - $video_offset_pixel))
      y=$(($res_y - $h - $video_offset_pixel))
   elif [ $position -eq 2 ]; then
      x=$video_offset_pixel
      y=$(($res_y - $h - $video_offset_pixel))   
   elif [ $position -eq 3 ]; then
      x=$video_offset_pixel
      y=$video_offset_pixel   
   fi
   xdotool windowmove $wid $x $y
   xdotool windowsize $wid $w $h
}

function play() {
   channel_string=$(svdrpsend -p $svdrp_port LSTE $channel now | grep 215-C | cut -d " " -f2)
   url=http://$streamdev_address:$streamdev_port/TS/$channel_string
   xine -S session=$xine_sessions,mrl=$url
}

function stop() {
   xine -S session=$xine_sessions,stop
   xine -S session=$xine_sessions,playlist=clear
}

function quit() {
   xine -S session=$xine_sessions,quit &
   sleep 1
   kill $pid
}

function save() {
   echo $res_x";"$res_y";"$channel_last";"$pid";"$wid";"$xine_sessions";"$channel";"$size";"$position > $tmp_file
}

function load() {
   tmp_values=$(cat $tmp_file)
   res_x=$(echo $tmp_values | cut -d ";" -f1)
   res_y=$(echo $tmp_values | cut -d ";" -f2)
   channel_last=$(echo $tmp_values | cut -d ";" -f3)
   pid=$(echo $tmp_values | cut -d ";" -f4)
   wid=$(echo $tmp_values | cut -d ";" -f5)
   xine_sessions=$(echo $tmp_values | cut -d ";" -f6)   
   channel=$(echo $tmp_values | cut -d ";" -f7)
   size=$(echo $tmp_values | cut -d ";" -f8)
   position=$(echo $tmp_values | cut -d ";" -f9)
}

function message() {
   if [ $activate_messages -eq 1 ]; then
      svdrpsend -p $svdrp_port MESG $1 &
   fi
}



export DISPLAY=$display
if [ -f $tmp_file ]; then
   load
   if [ -e /proc/$pid ]; then
      case "$1" in
         "")
            message "$msg_stop"
            quit
            ;;
         "-s")
            channel_temp=$(svdrpsend -p $svdrp_port CHAN | grep 250 | cut -d " " -f2)
            if [ $channel_temp -ne $channel ]; then
               message "$msg_swap"
               stop
               svdrpsend -p $svdrp_port CHAN $channel
               channel=$channel_temp
               play
            fi
            ;;
         "-n")
            if [ $channel -lt $channel_last ]; then
               message "$msg_next"
               stop
               channel=$(($channel + 1))
               play
            fi
            ;;
         "-p")
            if [ $channel -gt 1 ]; then
               message "$msg_previous"
               stop
               channel=$(($channel - 1))
               play
            fi
            ;;
         "-i")
            if [ $size -lt $video_size_max_percent ]; then
               size=$(($size + $video_size_step_percent))
               message "$msg_increase"
               set_size_and_position
            fi
            ;;
         "-d")
            if [ $size -gt $video_size_min_percent ]; then
               size=$(($size - $video_size_step_percent))
               message "$msg_decrease"
               set_size_and_position
            fi
            ;;
         "-m")
            if [ $position -eq 3 ]; then
               position=0
            else
               position=$(($position + 1))
            fi
            set_size_and_position
            ;;
      esac
   else
      case "$1" in
         "")
            message "$msg_start"
            start
            size=$video_size_start_percent
            position=0
            set_size_and_position
            channel=$(svdrpsend -p $svdrp_port CHAN | grep 250 | cut -d " " -f2)
            play
            ;;
         "-r")
            message "$msg_restore"
            start
            set_size_and_position
            play
            ;;
      esac
   fi
else
   message "$msg_start"
   start
   size=$video_size_start_percent
   position=0
   set_size_and_position
   channel=$(svdrpsend -p $svdrp_port CHAN | grep 250 | cut -d " " -f2)
   play
fi
save
exit 0

